import pandas as pd
import numpy as np
import matplotlib.pyplot as plt
import seaborn as sb
import scipy.stats as ss
import pystan
import pickle


flnm = input('Data File Name (*.xlsx) = ')
xlsx = pd.ExcelFile(flnm)                   #   入力ファイル名の設定
data = pd.read_excel(xlsx)                  #   読み込み

VarLabels = data.columns[1:].values;
print(VarLabels)

X = data.values[:, 1:]
X = ss.zscore(X)
X = X.T
Jpn = X[0]
Eng = X[1]
Hist = X[2]
Math = X[3]
Phys = X[4]
Chem = X[5]
N = len(Jpn)

Data = {'N': N, 'Jpn': Jpn, 'Eng': Eng, 'Hist': Hist, 'Math': Math, 'Phys': Phys, 'Chem': Chem}

def f_init():
    return dict(b1 = 0.9, b2 = 0.9, a = [0.9, 0.9, 0.9, 0.9, 0.9, 0.9])


sm = pystan.StanModel(file = 'SubjModel.stan')
fit = sm.sampling(data = Data, init = f_init, n_jobs = 1)

print(fit)

b1_smpls = fit['b1']
b2_smpls = fit['b2']
b1 = fit['b1'].mean()
b2 = fit['b2'].mean()
print('\nb1 = {0:.5}'.format(b1))
print('b2 = {0:.5}'.format(b2))
a = fit['a'].mean(axis = 0)
for i in range(6):
    print('a[{0:}] = {1:.5}'.format(i+1, a[i]))

sb.kdeplot(b1_smpls, label = 'b1')
sb.kdeplot(b2_smpls, label = 'b2')
plt.title('Means:\nb1 = {0:.3},  b2 = {1:.3}'.format(b1, b2), fontsize = 14)
plt.legend()
plt.show()

a_smpls = fit['a'].T
for i in range(6):
    sb.kdeplot(a_smpls[i], label = 'a{}'.format(i+1))
plt.legend()
plt.title(('Means: a1 = {0:.3},  a2 = {1:.3}\n' +
           'a3 = {2:.3},  a4 = {3:.3},  a5 = {4:.3},  a6 = {5:.3}').format(
               a[0], a[1], a[2], a[3], a[4], a[5]), fontsize = 14)
plt.show()

fJpn = fit['f_Jpn'].mean(axis = 0)
plt.plot(fJpn, Jpn, 'bo')
plt.ylabel('Jpn(std)')
plt.xlabel('fJpn')
plt.title('a1 = {0:.5}'.format(a[0]), fontsize = 14)
plt.show()

fEng = fit['f_Eng'].mean(axis = 0)
plt.plot(fEng, Eng, 'bo')
plt.xlabel('fEng')
plt.ylabel('Eng(std)')
plt.title('a2 = {0:.5}'.format(a[1]), fontsize = 14)
plt.show()

fHist = fit['f_Hist'].mean(axis = 0)
plt.plot(fHist, Hist, 'bo')
plt.xlabel('fHist')
plt.ylabel('Hist(std)')
plt.title('a3 = {0:.5}'.format(a[2]), fontsize = 14)
plt.show()

fMath = fit['f_Math'].mean(axis = 0)
plt.plot(fMath, Math, 'bo')
plt.xlabel('fMath')
plt.ylabel('Math(std)')
plt.title('a4 = {0:.5}'.format(a[3]), fontsize = 14)
plt.show()

fPhys = fit['f_Phys'].mean(axis = 0)
plt.plot(fPhys, Phys, 'bo')
plt.xlabel('fPhys')
plt.ylabel('Phys(std)')
plt.title('a5 = {0:.5}'.format(a[4]), fontsize = 14)
plt.show()

fChem = fit['f_Chem'].mean(axis = 0)
plt.plot(fChem, Chem, 'bo')
plt.xlabel('fChem')
plt.ylabel('Chem(std)')
plt.title('a6 = {0:.5}'.format(a[5]), fontsize = 14)
plt.show()
