data {
    int N;
    real Jpn[N];
    real Eng[N];
    real Hist[N];
    real Math[N];
    real Phys[N];
    real Chem[N];
}
parameters {
    real b1;
    real b2;
    real FG[N];
    real FL[N];
    real FS[N];
    real a[6];
}
transformed parameters {
    real f_Jpn[N];
    real f_Eng[N];
    real f_Hist[N];
    real f_Math[N];
    real f_Phys[N];
    real f_Chem[N];
    for (i in 1:N){
        f_Jpn[i] = a[1] * FL[i];
        f_Eng[i] = a[2] * FL[i];
        f_Hist[i] = a[3] * FL[i];
        f_Math[i] = a[4] * FS[i];
        f_Phys[i] = a[5] * FS[i];
        f_Chem[i] = a[6] * FS[i];
    }
}
model {
    b1 ~ uniform(0.0, 1.0);
    b2 ~ uniform(-1.0, 1.0);
    for (j in 1:6){
        a[j] ~ uniform(0.0, 1.0);
    }
    for (i in 1:N){
        FG[i] ~ normal(0, 1);
        FL[i] ~ normal(b1 * FG[i], sqrt(1 - b1 * b1));
        FS[i] ~ normal(b2 * FG[i], sqrt(1 - b2 * b2));
        Jpn[i] ~ normal(f_Jpn[i], sqrt(1 - a[1]*a[1]));
        Eng[i] ~ normal(f_Eng[i], sqrt(1 - a[2]*a[2]));
        Hist[i] ~ normal(f_Hist[i], sqrt(1 - a[3]*a[3]));
        Math[i] ~ normal(f_Math[i], sqrt(1 - a[4]*a[4]));
        Phys[i] ~ normal(f_Phys[i], sqrt(1 - a[5]*a[5]));
        Chem[i] ~ normal(f_Chem[i], sqrt(1 - a[6]*a[6]));
    }
}
